@@ -28,6 +28,9 @@ from .blocks import RowColIntType, RowColDoubleType, RangeAzimuthType, \
 
 logger = logging.getLogger(__name__)
 
+_sicd_type_text = 'Requires instance of SICDType,\n\tgot type `{}`'
+_exp_calc_text = 'Requires input which is an instance of ExploitationCalculator,\n\tgot type `{}`'
+
 
 class ExploitationCalculator(object):
     """
@@ -494,7 +497,7 @@ class ExploitationFeaturesCollectionInformationType(Serializable):
         """
 
         if not isinstance(sicd, SICDType):
-            raise TypeError('Requires SICDType instance, got type {}'.format(type(sicd)))
+            raise TypeError(_sicd_type_text.format(type(sicd)))
 
         polarizations = [
             TxRcvPolarizationType.from_sicd_value(entry.TxRcvPolarization)
@@ -592,8 +595,7 @@ class ExploitationFeaturesCollectionGeometryType(Serializable):
         """
 
         if not isinstance(calculator, ExploitationCalculator):
-            raise TypeError(
-                'Requires input which is an instance of ExploitationCalculator, got type {}'.format(type(calculator)))
+            raise TypeError(_exp_calc_text.format(type(calculator)))
 
         return cls(Azimuth=calculator.AzimuthAngle,
                    Slope=calculator.SlopeAngle,
@@ -675,8 +677,7 @@ class ExploitationFeaturesCollectionPhenomenologyType(Serializable):
         """
 
         if not isinstance(calculator, ExploitationCalculator):
-            raise TypeError(
-                'Requires input which is an instance of ExploitationCalculator, got type {}'.format(type(calculator)))
+            raise TypeError(_exp_calc_text.format(type(calculator)))
         return cls(Shadow=calculator.Shadow, Layover=calculator.Layover,
                    MultiPath=calculator.MultiPath, GroundTrack=calculator.GroundTrack)
 
@@ -742,8 +743,7 @@ class CollectionType(Serializable):
         """
 
         if not isinstance(calculator, ExploitationCalculator):
-            raise TypeError(
-                'Requires input which is an instance of ExploitationCalculator, got type {}'.format(type(calculator)))
+            raise TypeError(_exp_calc_text.format(type(calculator)))
 
         return cls(identifier=sicd.CollectionInfo.CoreName,
                    Information=ExploitationFeaturesCollectionInformationType.from_sicd(sicd),
@@ -826,7 +826,7 @@ class ExploitationFeaturesProductType(Serializable):
         """
 
         if not isinstance(sicd, SICDType):
-            raise TypeError('Requires SICDType instance, got type {}'.format(type(sicd)))
+            raise TypeError(_sicd_type_text.format(type(sicd)))
 
         row_ground, col_ground = sicd.get_ground_resolution()
         ellipticity = row_ground/col_ground if row_ground >= col_ground else col_ground/row_ground
@@ -899,7 +899,7 @@ class ExploitationFeaturesType(Serializable):
             return cls(Collections=collections, Products=feats)
 
         if not isinstance(sicd, SICDType):
-            raise TypeError('Requires SICDType instance, got type {}'.format(type(sicd)))
+            raise TypeError(_sicd_type_text.format(type(sicd)))
         calculator = ExploitationCalculator.from_sicd(sicd, row_vector, col_vector)
         return cls(
             Collections=[CollectionType.from_calculator(calculator, sicd), ],
